@@ -721,7 +721,8 @@ def delete_deployment(apiurl):
     
     # delete competition posting
     bodydata = {"apiurl": apiurl,
-                "delete":"TRUE"
+                "delete":"TRUE",
+                "experiment":"FALSE"
                                 }
 
     # Get the response
@@ -731,6 +732,19 @@ def delete_deployment(apiurl):
     requests.post("https://o35jwfakca.execute-api.us-east-1.amazonaws.com/dev/modeldata",
                   json=bodydata, headers=headers_with_authentication)
 
+    # delete experiment posting
+    bodydata = {"apiurl": apiurl,
+                "delete":"TRUE",
+                "experiment":"TRUE"
+                                }
+
+    # Get the response
+    headers_with_authentication = {'Content-Type': 'application/json', 'authorizationToken': os.environ.get("AWS_TOKEN"), 'Access-Control-Allow-Headers':
+                                    'Content-Type,X-Amz-Date,authorizationToken,Access-Control-Allow-Origin,X-Api-Key,X-Amz-Security-Token,Authorization', 'Access-Control-Allow-Origin': '*'}
+    # competitiondata lambda function invoked through below url to update model submissions and contributors
+    requests.post("https://o35jwfakca.execute-api.us-east-1.amazonaws.com/dev/modeldata",
+                  json=bodydata, headers=headers_with_authentication)    
+    
     # Delete competition data container image
     try:
             content_object = s3.Object(bucket_name=api_bucket, key=model_id + "/competitionuserdata.json")
@@ -774,4 +788,4 @@ __all__ = [
     get_api_json,
     create_prediction_api,
     delete_deployment
-]
\ No newline at end of file
+]
