@@ -809,12 +809,18 @@ def submit_model(
     # }}}
     modelsubmissiontags=input("Insert search tags to help users find your model (optional): ")
     modelsubmissiondescription=input("Provide any useful notes about your model (optional): ")
+    
+    if submission_type=="competition":
+        experimenttruefalse="FALSE"
+    else:
+        experimenttruefalse="TRUE"
 
-    #Update competition data
+    #Update competition or experiment data
     bodydata = {"apiurl": apiurl,
                 "submissions": model_version,
                   "contributoruniquenames":os.environ.get('username'),
-                "versionupdateputsubmit":"TRUE"
+                "versionupdateputsubmit":"TRUE",
+                 "experiment":experimenttruefalse
                                 }
 
     # Get the response
